// bootstrap
$base: #ff7043;
$primary: darken($base, 25%);
$font-family-sans-serif: 'Dosis', sans-serif !default;


// fonts
$h1-size: 1.6rem;
$h2-size: 1.4rem;
$h3-size: 1.2rem;

// utils
$transparent: transparent;
$warning-fg: darken(#ffc107, 10%);
$danger-fg: #dc3545;

// navbar
$navbar-bg: #37474f;
$navbar-link-color: #fff;
$navbar-dropdown-link-color: #000;
$navbar-link-color-hover: #ff7043;
$navbar-color: #fff;
$navbar-mobile-pane-bg: #263238;

// footer
$footer-bg: #b3c4cd;
$footer-link-color: #37474f;
$footer-link-color-hover: $primary;
$footer-color: #333;
$footer-border-color: #fff;

// menu
$menu-bg: #263238;
$menu-color: #fff;
$menu-branding-color: #fff;
$gravatar-border-color: #fff;
$menu-link-color: #ccc;
$menu-link-hover-color: #fff;
$menu-li-hover-bg: darken($menu-bg, 2%);
$menu-li-border-color: #444;
$menu-active-voice-bg: darken($primary, 10%);
$menu-active-voice-border-color: #f5f5f5;
$menu-mobile-title-bg: #37474f;
$menu-mobile-title-color: #fff;
$menu-mobile-title-border-color: rgba(255, 255, 255, .2);
$menu-mobile-back-bg: darken($menu-bg, 5%);
$menu-selected-sub-bg: lighten($menu-bg, 5%);
$menu-title-bg: darken($menu-mobile-title-bg, 5%);
$menu-voice-title-color: $base;
$menu-voice-title-bg: darken($menu-bg, 5%);
$menu-active-bg: #f5f5f5;
$menu-branding-bg: darken($menu-bg, 5%);

// dashboard
$dashboard-bg: #f5f5f5;
$dashboard-title-bg: #fff;
$dashboard-title-border-color: #ccc;
$dashboard-module-bg: #fff;
$dashboard-module-border-color: #ccc;
$dashboard-caption-bg: #f6f6f6;
$dashboard-caption-color: #000;
$dashboard-icon-color: #f90;

// breadcrumbs
$breadcrumbs-bg: #fcfcfc;
$breadcrumbs-border-color: #bbb;

// content
$content-bg: #f5f5f5;

// changelist
$changelist-bg: #fff;
$changelist-border-color: #ccc;
$toolbar-bg: lighten($navbar-mobile-pane-bg, 75%);
$toolbar-btn-bg: #fff;
$toolbar-btn-hover-bg: #fafafa;
$sort-icon-color: #999;
$filter-toggler-color: #fff;
$filters-bg: #fafafa;
$filters-title-bg: #263238;
$filters-title-color: #fff;
$filter-selected-border-color: $base;
$rl-head-bg: #f0f0f0;
$rl-head-color: inherit;
$rl-tr-odd-bg: #fafafa;
$rl-tr-odd-color: inherit;
$rl-tr-selected-bg-color: #cfc4a8;
$rl-tr-selected-bg: lighten($rl-tr-selected-bg-color, 10%);
$rl-tr-selected-color: inherit;

// changeform
$changeform-bg: #fff;
$changeform-border-color: #ccc;
$collapse-title-bg: #fafafa;
$collapse-title-border-color: #ccc;
$collapse-entry-icon-color: #666;
$state-danger-bg: #f2dede;
$field-bg: #f9f9f9;
$field-row-error-bg: $state-danger-bg;
$fieldset-title-bg: lighten($base, 30%);
$inline-related-title-bg: #fafafa;
$inline-related-title-border-color: #eee;
$inline-related-title-border-top-color: #eee;
$inline-changelink-bg: #ffe4dc;
$inline-tabular-original-bg: #fafafa;
$inline-tabular-original-border-color: #eee;
$help-text-color: #007eed;
$clockbox-title-bg: #eee;
$clockbox-title-border-color: #ddd;

// changeform spinner
$spinner-overlay-bg: rgba(255, 255, 255, .8);
$spinner-overlay-fg: #000;

// form components
$selector-item-border-color: #ccc;
$selector-available-title-bg: #fafafa;
$selector-chosen-title-bg: lighten($base, 30%);
$selector-chooser-bg: #eee;

// changehistory
$changehistory-bg: #fff;
$changehistory-border-color: #ccc;

// passwordchange
$passwordchange-bg: #fff;
$passwordchange-border-color: #ccc;

// pagination
$pag-bg: #fff;
$pag-hover-bg: #eee;
$pag-border-color: #eee;
$pag-color: #000;
$pag-selected-bg: #455a64;
$pag-selected-color: #fff;
$pag-selected-border-color: #455a64;

// delete confirmation
$delete-confirmation-bg: #fff;
$delete-confirmation-border-color: #ccc;

// analytics
$chart-bg: #fff;
$chart-border-color: #ccc;
