{% extends 'admin/change_form.html' %}
{% block content %}{{ block.super }}

{% for template, field, position in adminform.model_admin.baton_form_includes %}
    <template id="template-{{ field }}" data-position="{{ position }}">
        <div id='template-{{ field }}-container' class="baton-form-include">
            {% include template %}
        </div>
    </template>
{% endfor %}
{% endblock %}
