@font-face {
  font-family: 'Dosis';
  font-style: normal;
  font-weight: 300;
  src: url('../fonts/Dosis-Light.ttf') format('truetype');
}

@font-face {
  font-family: 'Dosis';
  font-style: normal;
  font-weight: 400;
  src: url('../fonts/Dosis-Regular.ttf') format('truetype');
}

@font-face {
  font-family: 'Dosis';
  font-style: normal;
  font-weight: 700;
  src: url('../fonts/Dosis-Bold.ttf') format('truetype');
}
